lilypondnametools
=================

.. automodule:: abjad.tools.lilypondnametools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting
      ~abjad.tools.lilypondnametools.LilyPondGrobNameManager.LilyPondGrobNameManager
      ~abjad.tools.lilypondnametools.LilyPondGrobOverride.LilyPondGrobOverride
      ~abjad.tools.lilypondnametools.LilyPondNameManager.LilyPondNameManager
      ~abjad.tools.lilypondnametools.LilyPondSettingNameManager.LilyPondSettingNameManager
